Contributors
============

Contributions to the project can be seen `here <https://github.com/INFN-MRI/mrtwin/graphs/contributors>`_

.. raw:: html

  <a href="https://github.com/INFN-MRI/mrtwin/graphs/contributors">
     <img src="https://contrib.rocks/image?repo=INFN-MRI/mrtwin" />
  </a>
